==> openjdk-src-11.0.1.u13-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fil.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fil extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_CNH = "CNH";
        final Object[][] data = new Object[][] {
            { "mwk", "Malawian Kwacha" },
            { "FJD", "FJD" },
            { "STD", "STD" },
            { "LVL", "LVL" },
            { "SCR", "SCR" },
            { "CDF", "CDF" },
            { "BBD", "BBD" },
            { "mga", "Malagasy Ariary" },
            { "HNL", "HNL" },
            { "UGX", "UGX" },
            { "ZAR", "ZAR" },
            { "dem", "Deutsche Marks" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "egp", "Egyptian Pound" },
            { "CUC", "CUC" },
            { "ssp", "Pound ng Timog Sudan" },
            { "BSD", "BSD" },
            { "nio", "C\u00f3rdoba ng Nicaragua" },
            { "SDG", "SDG" },
            { "nzd", "Dolyar ng New Zealand" },
            { "IQD", "IQD" },
            { "brl", "Real ng Barzil" },
            { "CUP", "CUP" },
            { "GMD", "GMD" },
            { "fjd", "Dolyar ng Fiji" },
            { "RSD", "RSD" },
            { "mxn", "Piso ng Mexico" },
            { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
            { "lvl", "Latvian Lats" },
            { "scr", "Seychellois Rupee" },
            { "cdf", "Congolese Franc" },
            { "bbd", "Dolyar ng Barbados" },
            { "MYR", "MYR" },
            { "hnl", "Lempira ng Honduras" },
            { "ugx", "Ugandan Shilling" },
            { "FKP", "FKP" },
            { "zar", "Rand ng Timog Africa" },
            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra" },
            { "UYU", "UYU" },
            { "cuc", "Convertible na Piso ng Cuba" },
            { "bsd", "Dolyar ng Bahamas" },
            { "CVE", "CVE" },
            { "OMR", "OMR" },
            { "sdg", "Pound ng Sudan" },
            { "KES", "KES" },
            { "SEK", "SEK" },
            { "BTN", "BTN" },
            { "iqd", "Iraqi Dinar" },
            { "GNF", "GNF" },
            { "cup", "Piso ng Cuba" },
            { "gmd", "Gambian Dalasi" },
            { "MZN", "MZN" },
            { "twd", "Dolyar ng New Taiwan" },
            { "ARS", "ARS" },
            { "rsd", "Serbian Dinar" },
            { "QAR", "QAR" },
            { "myr", "Malaysian Ringgit" },
            { "IRR", "IRR" },
            { "fkp", "Pound ng Falkland Islands" },
            { "xof", "CFA Franc ng Kanlurang Africa" },
            { "THB", "\u0e3f" },
            { "UZS", "UZS" },
            { "uyu", "Piso ng Uruguay" },
            { "BDT", "BDT" },
            { "cve", "Cape Verdean Escudo" },
            { "omr", "Omani Rial" },
            { "LYD", "LYD" },
            { "kes", "Kenyan Shilling" },
            { "sek", "Swedish Krona" },
            { "KWD", "KWD" },
            { "btn", "Bhutanese Ngultrum" },
            { "RUB", "RUB" },
            { "gnf", "Guinean Franc" },
            { "ISK", "ISK" },
            { "mzn", "Mozambican Metical" },
            { "ars", "Piso ng Argentina" },
            { "qar", "Qatari Rial" },
            { "MKD", "MKD" },
            { "irr", "Iranian Rial" },
            { "DZD", "DZD" },
            { "thb", "Thai Baht" },
            { "uzs", "Uzbekistan Som" },
            { "xpf", "CFP Franc" },
            { "PAB", "PAB" },
            { "SGD", "SGD" },
            { "bdt", "Bangladeshi Taka" },
            { "KGS", "KGS" },
            { "lyd", "Libyan Dinar" },
            { "kwd", "Kuwaiti Dinar" },
            { "rub", "Russian Ruble" },
            { "CHF", "CHF" },
            { "HRK", "HRK" },
            { "isk", "Icelandic Kr\u00f3na" },
            { "DJF", "DJF" },
            { "mkd", "Macedonian Denar" },
            { "TZS", "TZS" },
            { "dzd", "Algerian Dinar" },
            { "pab", "Balboa ng Panama" },
            { "sgd", "Dolyar ng Singapore" },
            { "KHR", "KHR" },
            { "IDR", "IDR" },
            { "kgs", "Kyrgystani Som" },
            { "KYD", "KYD" },
            { "BWP", "BWP" },
            { "SHP", "SHP" },
            { "TJS", "TJS" },
            { "xaf", "CFA Franc BEAC" },
            { "AED", "AED" },
            { "RWF", "RWF" },
            { "chf", "Swiss Franc" },
            { "hrk", "Croatian Kuna" },
            { "djf", "Djiboutian Franc" },
            { "DKK", "DKK" },
            { "BGN", "BGN" },
            { "MMK", "MMK" },
            { "NOK", "NOK" },
            { "SYP", "SYP" },
            { "tzs", "Tanzanian Shilling" },
            { "vnd", "Vietnamese Dong" },
            { "aud", "Dolyar ng Australya" },
            { "LKR", "LKR" },
            { "khr", "Cambodian Riel" },
            { "CZK", "CZK" },
            { "idr", "Indonesian Rupiah" },
            { "kyd", "Dolyar ng Cayman Islands" },
            { "HTG", "HTG" },
            { "bwp", "Botswanan Pula" },
            { "shp", "Saint Helena Pound" },
            { "tjs", "Tajikistani Somoni" },
            { "BHD", "BHD" },
            { "rwf", "Rwandan Franc" },
            { "aed", "United Arab Emirates Dirham" },
            { "KZT", "KZT" },
            { "SZL", "SZL" },
            { "dkk", "Danish Krone" },
            { "YER", "YER" },
            { "bgn", "Bulgarian Lev" },
            { "AFN", "AFN" },
            { "mmk", "Myanmar Kyat" },
            { "nok", "Norwegian Krone" },
            { "syp", "Syrian Pound" },
            { "AWG", "AWG" },
            { "NPR", "NPR" },
            { "MNT", "MNT" },
            { "lkr", "Sri Lankan Rupee" },
            { "czk", "Czech Republic Koruna" },
            { "BYN", "BYN" },
            { "HUF", "HUF" },
            { "xcd", "Dolyar ng Silangang Caribbean" },
            { "BYR", "BYR" },
            { "htg", "Gourde ng Haiti" },
            { "BIF", "BIF" },
            { "bhd", "Bahraini Dinar" },
            { "sit", "Slovenian Tolar" },
            { "kzt", "Kazakhstani Tenge" },
            { "szl", "Swazi Lilangeni" },
            { "yer", "Yemeni Rial" },
            { "afn", "Afghan Afghani" },
            { "BZD", "BZD" },
            { "MOP", "MOP" },
            { "NAD", "NAD" },
            { "awg", "Florin ng Aruba" },
            { "npr", "Nepalese Rupee" },
            { "mnt", "Mongolian Tugrik" },
            { "gbp", "British Pound" },
            { "byn", "Belarusian Ruble" },
            { "PEN", "PEN" },
            { "huf", "Hungarian Forint" },
            { "WST", "WST" },
            { "TMT", "TMT" },
            { "byr", "Belarusian Ruble (2000\u20132016)" },
            { "bif", "Burundian Franc" },
            { "GTQ", "GTQ" },
            { "CLP", "CLP" },
            { "TND", "TND" },
            { "bzd", "Dolyar ng Belize" },
            { "mop", "Macanese Pataca" },
            { "nad", "Dolyar ng Namibia" },
            { "SLL", "SLL" },
            { "skk", "Slovak Koruna" },
            { "pen", "Peruvian Sol" },
            { "wst", "Samoan Tala" },
            { "tmt", "Turkmenistani Manat" },
            { "frf", "French Franc" },
            { "DOP", "DOP" },
            { "KMF", "KMF" },
            { "gtq", "Quetzal ng Guatemala" },
            { "clp", "Piso ng Chile" },
            { "tnd", "Tunisian Dinar" },
            { "GEL", "GEL" },
            { "MAD", "MAD" },
            { "sll", "Sierra Leonean Leone" },
            { "TOP", "TOP" },
            { "AZN", "AZN" },
            { "PGK", "PGK" },
            { "CNH", metaValue_CNH },
            { "UAH", "UAH" },
            { "ERN", "ERN" },
            { "dop", "Piso ng Dominican" },
            { "kmf", "Comorian Franc" },
            { "MRO", "MRO" },
            { "gel", "Georgian Lari" },
            { "mad", "Moroccan Dirham" },
            { "azn", "Azerbaijani Manat" },
            { "top", "Tongan Pa\u02bbanga" },
            { "pgk", "Papua New Guinean Kina" },
            { "BMD", "BMD" },
            { "PHP", "\u20b1" },
            { "cnh", metaValue_CNH },
            { "uah", "Ukrainian Hryvnia" },
            { "PYG", "PYG" },
            { "JMD", "JMD" },
            { "ern", "Eritrean Nakfa" },
            { "COP", "COP" },
            { "USD", "$" },
            { "mro", "Mauritanian Ouguiya (1973\u20132017)" },
            { "cny", "Chinese Yuan" },
            { "mru", "Mauritanian Ouguiya" },
            { "ETB", "ETB" },
            { "SOS", "SOS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "LAK", "LAK" },
            { "bmd", "Dolyar ng Bermuda" },
            { "BND", "BND" },
            { "php", "Piso ng Pilipinas" },
            { "xxx", "Hindi Kilalang Pera" },
            { "LRD", "LRD" },
            { "pyg", "Paraguayan Guarani" },
            { "jmd", "Dolyar ng Jamaica" },
            { "ALL", "ALL" },
            { "ZMW", "ZMW" },
            { "cop", "Piso ng Colombia" },
            { "usd", "Dolyar ng US" },
            { "etb", "Ethiopian Birr" },
            { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
            { "GHS", "GHS" },
            { "GYD", "GYD" },
            { "KPW", "KPW" },
            { "BOB", "BOB" },
            { "MDL", "MDL" },
            { "sos", "Somali Shilling" },
            { "vef", "Bol\u00edvar ng Venezuela" },
            { "vuv", "Vanuatu Vatu" },
            { "lak", "Laotian Kip" },
            { "AMD", "AMD" },
            { "bnd", "Dolyar ng Brunei" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "TRY", "TRY" },
            { "LBP", "LBP" },
            { "JOD", "JOD" },
            { "lrd", "Dolyar ng Liberia" },
            { "all", "Albanian Lek" },
            { "zmw", "Zambian Kwacha" },
            { "MUR", "MUR" },
            { "GIP", "GIP" },
            { "RON", "RON" },
            { "ils", "Israeli New Sheqel" },
            { "ghs", "Ghanaian Cedi" },
            { "gyd", "Dolyar ng Guyanese" },
            { "kpw", "Won ng Hilagang Korea" },
            { "NGN", "NGN" },
            { "bob", "Boliviano ng Bolivia" },
            { "mdl", "Moldovan Leu" },
            { "CRC", "CRC" },
            { "PKR", "PKR" },
            { "amd", "Armenian Dram" },
            { "ANG", "ANG" },
            { "try", "Turkish Lira" },
            { "lbp", "Pound ng Lebanon" },
            { "jod", "Jordanian Dinar" },
            { "hkd", "Dolyar ng Hong Kong" },
            { "eur", "Euro" },
            { "SRD", "SRD" },
            { "lsl", "Lesotho Loti" },
            { "LTL", "LTL" },
            { "SAR", "SAR" },
            { "TTD", "TTD" },
            { "cad", "Dolyar ng Canada" },
            { "MVR", "MVR" },
            { "eek", "Estonian Kroon" },
            { "mur", "Mauritian Rupee" },
            { "gip", "Gibraltar Pound" },
            { "ron", "Romanian Leu" },
            { "JPY", "\u00a5" },
            { "AOA", "AOA" },
            { "PLN", "PLN" },
            { "SBD", "SBD" },
            { "ngn", "Nigerian Naira" },
            { "crc", "Col\u00f3n ng Costa Rica" },
            { "pkr", "Pakistani Rupee" },
            { "ang", "Antillean Guilder ng Netherlands" },
            { "MWK", "MWK" },
            { "srd", "Dolyar ng Suriname" },
            { "ltl", "Lithuanian Litas" },
            { "sar", "Saudi Riyal" },
            { "ttd", "Dolyar ng Trinidad and Tobago" },
            { "MGA", "MGA" },
            { "mvr", "Maldivian Rufiyaa" },
            { "inr", "Indian Rupee" },
            { "BAM", "BAM" },
            { "EGP", "EGP" },
            { "SSP", "SSP" },
            { "krw", "Won ng Timog Korea" },
            { "aoa", "Angolan Kwanza" },
            { "jpy", "Japanese Yen" },
            { "pln", "Polish Zloty" },
            { "sbd", "Dolyar ng Solomon Islands" },
            { "NIO", "NIO" },
        };
        return data;
    }
}

==> openjdk-src-13.0.2.u8-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fil.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fil extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AMD", "AMD" },
            { "AOA", "AOA" },
            { "AZN", "AZN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BWP", "BWP" },
            { "CDF", "CDF" },
            { "CVE", "CVE" },
            { "DJF", "DJF" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "IQD", "IQD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KMF", "KMF" },
            { "KWD", "KWD" },
            { "KZT", "KZT" },
            { "LBP", "LBP" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MGA", "MGA" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MWK", "MWK" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "OMR", "OMR" },
            { "PGK", "PGK" },
            { "PHP", "\u20b1" },
            { "QAR", "QAR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TZS", "TZS" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UZS", "UZS" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "United Arab Emirates Dirham" },
            { "afn", "Afghan Afghani" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Antillean Guilder ng Netherlands" },
            { "aoa", "Angolan Kwanza" },
            { "ars", "Piso ng Argentina" },
            { "aud", "Dolyar ng Australya" },
            { "awg", "Florin ng Aruba" },
            { "azn", "Azerbaijani Manat" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "Dolyar ng Barbados" },
            { "bdt", "Bangladeshi Taka" },
            { "bgn", "Bulgarian Lev" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Dolyar ng Bermuda" },
            { "bnd", "Dolyar ng Brunei" },
            { "bob", "Boliviano ng Bolivia" },
            { "brl", "Real ng Barzil" },
            { "bsd", "Dolyar ng Bahamas" },
            { "btn", "Bhutanese Ngultrum" },
            { "bwp", "Botswanan Pula" },
            { "byn", "Belarusian Ruble" },
            { "byr", "Belarusian Ruble (2000\u20132016)" },
            { "bzd", "Dolyar ng Belize" },
            { "cad", "Dolyar ng Canada" },
            { "cdf", "Congolese Franc" },
            { "chf", "Swiss Franc" },
            { "clp", "Piso ng Chile" },
            { "cny", "Chinese Yuan" },
            { "cop", "Piso ng Colombia" },
            { "crc", "Col\u00f3n ng Costa Rica" },
            { "cuc", "Convertible na Piso ng Cuba" },
            { "cup", "Piso ng Cuba" },
            { "cve", "Cape Verdean Escudo" },
            { "czk", "Czech Republic Koruna" },
            { "dem", "Deutsche Marks" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Piso ng Dominican" },
            { "dzd", "Algerian Dinar" },
            { "eek", "Estonian Kroon" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fjd", "Dolyar ng Fiji" },
            { "fkp", "Pound ng Falkland Islands" },
            { "frf", "French Franc" },
            { "gbp", "British Pound" },
            { "gel", "Georgian Lari" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gtq", "Quetzal ng Guatemala" },
            { "gyd", "Dolyar ng Guyanese" },
            { "hkd", "Dolyar ng Hong Kong" },
            { "hnl", "Lempira ng Honduras" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Gourde ng Haiti" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "ils", "Israeli New Sheqel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isk", "Icelandic Kr\u00f3na" },
            { "jmd", "Dolyar ng Jamaica" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "Won ng Hilagang Korea" },
            { "krw", "Won ng Timog Korea" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Dolyar ng Cayman Islands" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Pound ng Lebanon" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Dolyar ng Liberia" },
            { "lsl", "Lesotho Loti" },
            { "ltl", "Lithuanian Litas" },
            { "lvl", "Latvian Lats" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mkd", "Macedonian Denar" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mro", "Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "Ouguiya ng Mauritania" },
            { "mur", "Mauritian Rupee" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Piso ng Mexico" },
            { "myr", "Malaysian Ringgit" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Dolyar ng Namibia" },
            { "ngn", "Nigerian Naira" },
            { "nio", "C\u00f3rdoba ng Nicaragua" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "Dolyar ng New Zealand" },
            { "omr", "Omani Rial" },
            { "pab", "Balboa ng Panama" },
            { "pen", "Peruvian Sol" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Piso ng Pilipinas" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Dolyar ng Solomon Islands" },
            { "scr", "Seychellois Rupee" },
            { "sdg", "Pound ng Sudan" },
            { "sek", "Swedish Krona" },
            { "sgd", "Dolyar ng Singapore" },
            { "shp", "Saint Helena Pound" },
            { "sit", "Slovenian Tolar" },
            { "skk", "Slovak Koruna" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Dolyar ng Suriname" },
            { "ssp", "Pound ng Timog Sudan" },
            { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (2018)" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjs", "Tajikistani Somoni" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "try", "Turkish Lira" },
            { "ttd", "Dolyar ng Trinidad and Tobago" },
            { "twd", "Dolyar ng New Taiwan" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "Dolyar ng US" },
            { "uyu", "Piso ng Uruguay" },
            { "uzs", "Uzbekistan Som" },
            { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
            { "vef", "Bol\u00edvar ng Venezuela (2008\u20132018)" },
            { "ves", "Bol\u00edvar ng Venezuela" },
            { "vnd", "Vietnamese Dong" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "CFA Franc BEAC" },
            { "xcd", "Dolyar ng Silangang Caribbean" },
            { "xof", "CFA Franc ng Kanlurang Africa" },
            { "xpf", "CFP Franc" },
            { "xxx", "Hindi Kilalang Pera" },
            { "yer", "Yemeni Rial" },
            { "zar", "Rand ng Timog Africa" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "zmw", "Zambian Kwacha" },
        };
        return data;
    }
}
